gchecky.test

Package gchecky :: Package test |
[hide private]
[frames] | no frames]

# Source Code for Package gchecky.test

     1  import unittest
     2
     3  from gchecky.test.gxml import *
     4  from gchecky.test.controller import *
     5
     6 -def allTestSuite():
     7      suite = unittest.TestSuite()
     8      suite.addTest(xmlFieldSuite())
     9      suite.addTest(xmlNodeSuite())
    10      suite.addTest(controllerSuite())
    11      return suite
    12
    13  if __name__ == '__main__':
    14      runner = unittest.TextTestRunner()
    15      runner.run(allTestSuite)
    16